.. aermanager documentation master file, created by
   sphinx-quickstart on Tue Nov 24 15:17:21 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to aermanager's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

How to
======

.. toctree::
   notebooks/How_to

Data Annotation
===============

.. toctree::
   notebooks/Annotations Tutorial

API
===

.. toctree::
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
